/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtPositioning.h"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeorectangle.sip"
#include <qgeorectangle.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoRectangle.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeocoordinate.sip"
#include <qgeocoordinate.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoRectangle.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoRectangle.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtPositioning/qgeoshape.sip"
#include <qgeoshape.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoRectangle.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtPositioning/sipQtPositioningQGeoRectangle.cpp"


PyDoc_STRVAR(doc_QGeoRectangle_setTopLeft, "setTopLeft(self, topLeft: QGeoCoordinate)");

extern "C" {static PyObject *meth_QGeoRectangle_setTopLeft(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_setTopLeft(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCoordinate* a0;
        ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoRectangle, &sipCpp, sipType_QGeoCoordinate, &a0))
        {
            sipCpp->setTopLeft(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_setTopLeft, doc_QGeoRectangle_setTopLeft);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_topLeft, "topLeft(self) -> QGeoCoordinate");

extern "C" {static PyObject *meth_QGeoRectangle_topLeft(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_topLeft(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRectangle, &sipCpp))
        {
            ::QGeoCoordinate*sipRes;

            sipRes = new ::QGeoCoordinate(sipCpp->topLeft());

            return sipConvertFromNewType(sipRes, sipType_QGeoCoordinate, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_topLeft, doc_QGeoRectangle_topLeft);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_setTopRight, "setTopRight(self, topRight: QGeoCoordinate)");

extern "C" {static PyObject *meth_QGeoRectangle_setTopRight(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_setTopRight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCoordinate* a0;
        ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoRectangle, &sipCpp, sipType_QGeoCoordinate, &a0))
        {
            sipCpp->setTopRight(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_setTopRight, doc_QGeoRectangle_setTopRight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_topRight, "topRight(self) -> QGeoCoordinate");

extern "C" {static PyObject *meth_QGeoRectangle_topRight(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_topRight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRectangle, &sipCpp))
        {
            ::QGeoCoordinate*sipRes;

            sipRes = new ::QGeoCoordinate(sipCpp->topRight());

            return sipConvertFromNewType(sipRes, sipType_QGeoCoordinate, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_topRight, doc_QGeoRectangle_topRight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_setBottomLeft, "setBottomLeft(self, bottomLeft: QGeoCoordinate)");

extern "C" {static PyObject *meth_QGeoRectangle_setBottomLeft(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_setBottomLeft(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCoordinate* a0;
        ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoRectangle, &sipCpp, sipType_QGeoCoordinate, &a0))
        {
            sipCpp->setBottomLeft(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_setBottomLeft, doc_QGeoRectangle_setBottomLeft);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_bottomLeft, "bottomLeft(self) -> QGeoCoordinate");

extern "C" {static PyObject *meth_QGeoRectangle_bottomLeft(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_bottomLeft(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRectangle, &sipCpp))
        {
            ::QGeoCoordinate*sipRes;

            sipRes = new ::QGeoCoordinate(sipCpp->bottomLeft());

            return sipConvertFromNewType(sipRes, sipType_QGeoCoordinate, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_bottomLeft, doc_QGeoRectangle_bottomLeft);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_setBottomRight, "setBottomRight(self, bottomRight: QGeoCoordinate)");

extern "C" {static PyObject *meth_QGeoRectangle_setBottomRight(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_setBottomRight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCoordinate* a0;
        ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoRectangle, &sipCpp, sipType_QGeoCoordinate, &a0))
        {
            sipCpp->setBottomRight(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_setBottomRight, doc_QGeoRectangle_setBottomRight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_bottomRight, "bottomRight(self) -> QGeoCoordinate");

extern "C" {static PyObject *meth_QGeoRectangle_bottomRight(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_bottomRight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRectangle, &sipCpp))
        {
            ::QGeoCoordinate*sipRes;

            sipRes = new ::QGeoCoordinate(sipCpp->bottomRight());

            return sipConvertFromNewType(sipRes, sipType_QGeoCoordinate, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_bottomRight, doc_QGeoRectangle_bottomRight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_setCenter, "setCenter(self, center: QGeoCoordinate)");

extern "C" {static PyObject *meth_QGeoRectangle_setCenter(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_setCenter(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCoordinate* a0;
        ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoRectangle, &sipCpp, sipType_QGeoCoordinate, &a0))
        {
            sipCpp->setCenter(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_setCenter, doc_QGeoRectangle_setCenter);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_center, "center(self) -> QGeoCoordinate");

extern "C" {static PyObject *meth_QGeoRectangle_center(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_center(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRectangle, &sipCpp))
        {
            ::QGeoCoordinate*sipRes;

            sipRes = new ::QGeoCoordinate(sipCpp->center());

            return sipConvertFromNewType(sipRes, sipType_QGeoCoordinate, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_center, doc_QGeoRectangle_center);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_setWidth, "setWidth(self, degreesWidth: float)");

extern "C" {static PyObject *meth_QGeoRectangle_setWidth(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_setWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QGeoRectangle, &sipCpp, &a0))
        {
            sipCpp->setWidth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_setWidth, doc_QGeoRectangle_setWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_width, "width(self) -> float");

extern "C" {static PyObject *meth_QGeoRectangle_width(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_width(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRectangle, &sipCpp))
        {
            double sipRes;

            sipRes = sipCpp->width();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_width, doc_QGeoRectangle_width);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_setHeight, "setHeight(self, degreesHeight: float)");

extern "C" {static PyObject *meth_QGeoRectangle_setHeight(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_setHeight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QGeoRectangle, &sipCpp, &a0))
        {
            sipCpp->setHeight(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_setHeight, doc_QGeoRectangle_setHeight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_height, "height(self) -> float");

extern "C" {static PyObject *meth_QGeoRectangle_height(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_height(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRectangle, &sipCpp))
        {
            double sipRes;

            sipRes = sipCpp->height();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_height, doc_QGeoRectangle_height);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_contains, "contains(self, rectangle: QGeoRectangle) -> bool");

extern "C" {static PyObject *meth_QGeoRectangle_contains(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_contains(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRectangle* a0;
        const ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoRectangle, &sipCpp, sipType_QGeoRectangle, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->contains(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_contains, doc_QGeoRectangle_contains);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_intersects, "intersects(self, rectangle: QGeoRectangle) -> bool");

extern "C" {static PyObject *meth_QGeoRectangle_intersects(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_intersects(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRectangle* a0;
        const ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoRectangle, &sipCpp, sipType_QGeoRectangle, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->intersects(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_intersects, doc_QGeoRectangle_intersects);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_translate, "translate(self, degreesLatitude: float, degreesLongitude: float)");

extern "C" {static PyObject *meth_QGeoRectangle_translate(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_translate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        double a1;
        ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QGeoRectangle, &sipCpp, &a0, &a1))
        {
            sipCpp->translate(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_translate, doc_QGeoRectangle_translate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_translated, "translated(self, degreesLatitude: float, degreesLongitude: float) -> QGeoRectangle");

extern "C" {static PyObject *meth_QGeoRectangle_translated(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_translated(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        double a1;
        const ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QGeoRectangle, &sipCpp, &a0, &a1))
        {
            ::QGeoRectangle*sipRes;

            sipRes = new ::QGeoRectangle(sipCpp->translated(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QGeoRectangle, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_translated, doc_QGeoRectangle_translated);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_united, "united(self, rectangle: QGeoRectangle) -> QGeoRectangle");

extern "C" {static PyObject *meth_QGeoRectangle_united(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_united(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRectangle* a0;
        const ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoRectangle, &sipCpp, sipType_QGeoRectangle, &a0))
        {
            ::QGeoRectangle*sipRes;

            sipRes = new ::QGeoRectangle(sipCpp->united(*a0));

            return sipConvertFromNewType(sipRes, sipType_QGeoRectangle, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_united, doc_QGeoRectangle_united);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_toString, "toString(self) -> str");

extern "C" {static PyObject *meth_QGeoRectangle_toString(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_toString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QGeoRectangle, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_toString, doc_QGeoRectangle_toString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QGeoRectangle_extendRectangle, "extendRectangle(self, coordinate: QGeoCoordinate)");

extern "C" {static PyObject *meth_QGeoRectangle_extendRectangle(PyObject *, PyObject *);}
static PyObject *meth_QGeoRectangle_extendRectangle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoCoordinate* a0;
        ::QGeoRectangle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QGeoRectangle, &sipCpp, sipType_QGeoCoordinate, &a0))
        {
            sipCpp->extendRectangle(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QGeoRectangle, sipName_extendRectangle, doc_QGeoRectangle_extendRectangle);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QGeoRectangle___or__(PyObject *, PyObject *);}
static PyObject *slot_QGeoRectangle___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QGeoRectangle* a0;
        const ::QGeoRectangle* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QGeoRectangle, &a0, sipType_QGeoRectangle, &a1))
        {
            ::QGeoRectangle*sipRes;

            sipRes = new ::QGeoRectangle((*a0 | *a1));

            return sipConvertFromNewType(sipRes, sipType_QGeoRectangle, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtPositioning, or_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QGeoRectangle___ior__(PyObject *, PyObject *);}
static PyObject *slot_QGeoRectangle___ior__(PyObject *sipSelf, PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QGeoRectangle)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

    ::QGeoRectangle *sipCpp = reinterpret_cast< ::QGeoRectangle *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QGeoRectangle));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QGeoRectangle* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QGeoRectangle, &a0))
        {
            sipCpp->::QGeoRectangle::operator|=(*a0);

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QGeoRectangle(void *, const sipTypeDef *);}
static void *cast_QGeoRectangle(void *sipCppV, const sipTypeDef *targetType)
{
    ::QGeoRectangle *sipCpp = reinterpret_cast< ::QGeoRectangle *>(sipCppV);

    if (targetType == sipType_QGeoRectangle)
        return sipCppV;

    if (targetType == sipType_QGeoShape)
        return static_cast< ::QGeoShape *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QGeoRectangle(void *, int);}
static void release_QGeoRectangle(void *sipCppV, int)
{
    delete reinterpret_cast< ::QGeoRectangle *>(sipCppV);
}


extern "C" {static void *array_QGeoRectangle(Py_ssize_t);}
static void *array_QGeoRectangle(Py_ssize_t sipNrElem)
{
    return new ::QGeoRectangle[sipNrElem];
}


extern "C" {static void array_delete_QGeoRectangle(void *);}
static void array_delete_QGeoRectangle(void *sipCpp)
{
    delete[] reinterpret_cast< ::QGeoRectangle *>(sipCpp);
}


extern "C" {static void assign_QGeoRectangle(void *, Py_ssize_t, void *);}
static void assign_QGeoRectangle(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QGeoRectangle *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QGeoRectangle *>(sipSrc);
}


extern "C" {static void *copy_QGeoRectangle(const void *, Py_ssize_t);}
static void *copy_QGeoRectangle(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QGeoRectangle(reinterpret_cast<const ::QGeoRectangle *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QGeoRectangle(sipSimpleWrapper *);}
static void dealloc_QGeoRectangle(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QGeoRectangle(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QGeoRectangle(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QGeoRectangle(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QGeoRectangle *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QGeoRectangle();

            return sipCpp;
        }
    }

    {
        const ::QGeoCoordinate* a0;
        double a1;
        double a2;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9dd", sipType_QGeoCoordinate, &a0, &a1, &a2))
        {
            sipCpp = new ::QGeoRectangle(*a0, a1, a2);

            return sipCpp;
        }
    }

    {
        const ::QGeoCoordinate* a0;
        const ::QGeoCoordinate* a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9J9", sipType_QGeoCoordinate, &a0, sipType_QGeoCoordinate, &a1))
        {
            sipCpp = new ::QGeoRectangle(*a0, *a1);

            return sipCpp;
        }
    }

    {
        const QList< ::QGeoCoordinate>* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QList_0100QGeoCoordinate, &a0, &a0State))
        {
            sipCpp = new ::QGeoRectangle(*a0);
            sipReleaseType(const_cast<QList< ::QGeoCoordinate> *>(a0), sipType_QList_0100QGeoCoordinate, a0State);

            return sipCpp;
        }
    }

    {
        const ::QGeoRectangle* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QGeoRectangle, &a0))
        {
            sipCpp = new ::QGeoRectangle(*a0);

            return sipCpp;
        }
    }

    {
        const ::QGeoShape* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QGeoShape, &a0))
        {
            sipCpp = new ::QGeoRectangle(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QGeoRectangle[] = {{25, 255, 1}};


/* Define this type's Python slots. */
static sipPySlotDef slots_QGeoRectangle[] = {
    {(void *)slot_QGeoRectangle___or__, or_slot},
    {(void *)slot_QGeoRectangle___ior__, ior_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QGeoRectangle[] = {
    {sipName_bottomLeft, meth_QGeoRectangle_bottomLeft, METH_VARARGS, doc_QGeoRectangle_bottomLeft},
    {sipName_bottomRight, meth_QGeoRectangle_bottomRight, METH_VARARGS, doc_QGeoRectangle_bottomRight},
    {sipName_center, meth_QGeoRectangle_center, METH_VARARGS, doc_QGeoRectangle_center},
    {sipName_contains, meth_QGeoRectangle_contains, METH_VARARGS, doc_QGeoRectangle_contains},
    {sipName_extendRectangle, meth_QGeoRectangle_extendRectangle, METH_VARARGS, doc_QGeoRectangle_extendRectangle},
    {sipName_height, meth_QGeoRectangle_height, METH_VARARGS, doc_QGeoRectangle_height},
    {sipName_intersects, meth_QGeoRectangle_intersects, METH_VARARGS, doc_QGeoRectangle_intersects},
    {sipName_setBottomLeft, meth_QGeoRectangle_setBottomLeft, METH_VARARGS, doc_QGeoRectangle_setBottomLeft},
    {sipName_setBottomRight, meth_QGeoRectangle_setBottomRight, METH_VARARGS, doc_QGeoRectangle_setBottomRight},
    {sipName_setCenter, meth_QGeoRectangle_setCenter, METH_VARARGS, doc_QGeoRectangle_setCenter},
    {sipName_setHeight, meth_QGeoRectangle_setHeight, METH_VARARGS, doc_QGeoRectangle_setHeight},
    {sipName_setTopLeft, meth_QGeoRectangle_setTopLeft, METH_VARARGS, doc_QGeoRectangle_setTopLeft},
    {sipName_setTopRight, meth_QGeoRectangle_setTopRight, METH_VARARGS, doc_QGeoRectangle_setTopRight},
    {sipName_setWidth, meth_QGeoRectangle_setWidth, METH_VARARGS, doc_QGeoRectangle_setWidth},
    {sipName_toString, meth_QGeoRectangle_toString, METH_VARARGS, doc_QGeoRectangle_toString},
    {sipName_topLeft, meth_QGeoRectangle_topLeft, METH_VARARGS, doc_QGeoRectangle_topLeft},
    {sipName_topRight, meth_QGeoRectangle_topRight, METH_VARARGS, doc_QGeoRectangle_topRight},
    {sipName_translate, meth_QGeoRectangle_translate, METH_VARARGS, doc_QGeoRectangle_translate},
    {sipName_translated, meth_QGeoRectangle_translated, METH_VARARGS, doc_QGeoRectangle_translated},
    {sipName_united, meth_QGeoRectangle_united, METH_VARARGS, doc_QGeoRectangle_united},
    {sipName_width, meth_QGeoRectangle_width, METH_VARARGS, doc_QGeoRectangle_width}
};

PyDoc_STRVAR(doc_QGeoRectangle, "\1QGeoRectangle()\n"
"QGeoRectangle(center: QGeoCoordinate, degreesWidth: float, degreesHeight: float)\n"
"QGeoRectangle(topLeft: QGeoCoordinate, bottomRight: QGeoCoordinate)\n"
"QGeoRectangle(coordinates: Iterable[QGeoCoordinate])\n"
"QGeoRectangle(other: QGeoRectangle)\n"
"QGeoRectangle(other: QGeoShape)");


sipClassTypeDef sipTypeDef_QtPositioning_QGeoRectangle = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QGeoRectangle,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QGeoRectangle,
        {0, 0, 1},
        21, methods_QGeoRectangle,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QGeoRectangle,
    -1,
    -1,
    supers_QGeoRectangle,
    slots_QGeoRectangle,
    init_type_QGeoRectangle,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QGeoRectangle,
    assign_QGeoRectangle,
    array_QGeoRectangle,
    copy_QGeoRectangle,
    release_QGeoRectangle,
    cast_QGeoRectangle,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QGeoRectangle,
    sizeof (::QGeoRectangle),
};
